# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: i4t/protobuf/Firmware.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from i4t.protobuf import common_pb2 as i4t_dot_protobuf_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='i4t/protobuf/Firmware.proto',
  package='i4t.protobuf',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1bi4t/protobuf/Firmware.proto\x12\x0ci4t.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19i4t/protobuf/common.proto\"\xa7\x03\n\x13\x46irmwareTokenClaims\x12\x0b\n\x03iss\x18\x01 \x01(\t\x12\x0b\n\x03sub\x18\x02 \x01(\t\x12\x0b\n\x03\x61ud\x18\x03 \x01(\t\x12\'\n\x03\x65xp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03nbf\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03iat\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03jti\x18\x07 \x01(\t\x12\x0e\n\x06public\x18\x08 \x01(\x0c\x12\x0f\n\x07private\x18\t \x01(\x0c\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x0c\n\x04size\x18\x0c \x01(\r\x12\x0e\n\x06\x62inary\x18\r \x01(\x0c\x12\x11\n\tfile_name\x18\x0e \x01(\t\x12\x36\n\tfile_type\x18\x0f \x01(\x0e\x32#.i4t.protobuf.FirmwareFileType.Enum\x12\x11\n\tfile_hash\x18\x10 \x01(\x0c\x12\x33\n\x0e\x66ile_hash_type\x18\x11 \x01(\x0e\x32\x1b.i4t.protobuf.HashType.Enum\"\x92\x01\n\x10\x46irmwareFileType\"~\n\x04\x45num\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x42IN\x10\x01\x12\x07\n\x03HEX\x10\x02\x12\x07\n\x03\x45LF\x10\x03\x12\x07\n\x03MAP\x10\x04\x12\x07\n\x03IMG\x10\x05\x12\x07\n\x03TAR\x10\x0b\x12\n\n\x06TAR_BZ\x10\x0c\x12\n\n\x06TAR_GZ\x10\r\x12\n\n\x06TAR_XZ\x10\x0e\x12\x07\n\x03ZIP\x10\x15\x12\x06\n\x02Z7\x10\x16\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,i4t_dot_protobuf_dot_common__pb2.DESCRIPTOR,])



_FIRMWAREFILETYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='i4t.protobuf.FirmwareFileType.Enum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEX', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ELF', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAP', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMG', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAR', index=6, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAR_BZ', index=7, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAR_GZ', index=8, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAR_XZ', index=9, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ZIP', index=10, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Z7', index=11, number=22,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=552,
  serialized_end=678,
)
_sym_db.RegisterEnumDescriptor(_FIRMWAREFILETYPE_ENUM)


_FIRMWARETOKENCLAIMS = _descriptor.Descriptor(
  name='FirmwareTokenClaims',
  full_name='i4t.protobuf.FirmwareTokenClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iss', full_name='i4t.protobuf.FirmwareTokenClaims.iss', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub', full_name='i4t.protobuf.FirmwareTokenClaims.sub', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aud', full_name='i4t.protobuf.FirmwareTokenClaims.aud', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exp', full_name='i4t.protobuf.FirmwareTokenClaims.exp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nbf', full_name='i4t.protobuf.FirmwareTokenClaims.nbf', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iat', full_name='i4t.protobuf.FirmwareTokenClaims.iat', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jti', full_name='i4t.protobuf.FirmwareTokenClaims.jti', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public', full_name='i4t.protobuf.FirmwareTokenClaims.public', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private', full_name='i4t.protobuf.FirmwareTokenClaims.private', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='i4t.protobuf.FirmwareTokenClaims.version', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='i4t.protobuf.FirmwareTokenClaims.size', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='i4t.protobuf.FirmwareTokenClaims.binary', index=11,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='i4t.protobuf.FirmwareTokenClaims.file_name', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='i4t.protobuf.FirmwareTokenClaims.file_type', index=13,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_hash', full_name='i4t.protobuf.FirmwareTokenClaims.file_hash', index=14,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_hash_type', full_name='i4t.protobuf.FirmwareTokenClaims.file_hash_type', index=15,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=529,
)


_FIRMWAREFILETYPE = _descriptor.Descriptor(
  name='FirmwareFileType',
  full_name='i4t.protobuf.FirmwareFileType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FIRMWAREFILETYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=678,
)

_FIRMWARETOKENCLAIMS.fields_by_name['exp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FIRMWARETOKENCLAIMS.fields_by_name['nbf'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FIRMWARETOKENCLAIMS.fields_by_name['iat'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FIRMWARETOKENCLAIMS.fields_by_name['file_type'].enum_type = _FIRMWAREFILETYPE_ENUM
_FIRMWARETOKENCLAIMS.fields_by_name['file_hash_type'].enum_type = i4t_dot_protobuf_dot_common__pb2._HASHTYPE_ENUM
_FIRMWAREFILETYPE_ENUM.containing_type = _FIRMWAREFILETYPE
DESCRIPTOR.message_types_by_name['FirmwareTokenClaims'] = _FIRMWARETOKENCLAIMS
DESCRIPTOR.message_types_by_name['FirmwareFileType'] = _FIRMWAREFILETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FirmwareTokenClaims = _reflection.GeneratedProtocolMessageType('FirmwareTokenClaims', (_message.Message,), dict(
  DESCRIPTOR = _FIRMWARETOKENCLAIMS,
  __module__ = 'i4t.protobuf.Firmware_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.FirmwareTokenClaims)
  ))
_sym_db.RegisterMessage(FirmwareTokenClaims)

FirmwareFileType = _reflection.GeneratedProtocolMessageType('FirmwareFileType', (_message.Message,), dict(
  DESCRIPTOR = _FIRMWAREFILETYPE,
  __module__ = 'i4t.protobuf.Firmware_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.FirmwareFileType)
  ))
_sym_db.RegisterMessage(FirmwareFileType)


# @@protoc_insertion_point(module_scope)
