# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: i4t/protobuf/Instancing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pbose.protobuf import PbWK_pb2 as pbose_dot_protobuf_dot_PbWK__pb2
from pbose.protobuf import PbWS_pb2 as pbose_dot_protobuf_dot_PbWS__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='i4t/protobuf/Instancing.proto',
  package='i4t.protobuf',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1di4t/protobuf/Instancing.proto\x12\x0ci4t.protobuf\x1a\x19pbose/protobuf/PbWK.proto\x1a\x19pbose/protobuf/PbWS.proto\"\xda\x01\n\x15InstancingTokenClaims\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.pbose.protobuf.PbWK\x12\x0e\n\x06serial\x18\x02 \x01(\t\x12\x0b\n\x03sku\x18\x03 \x01(\t\x12\x0b\n\x03upc\x18\x04 \x01(\x04\x12\x19\n\x11manufacturer_name\x18\x05 \x01(\t\x12\x1d\n\x15manufacturer_location\x18\x06 \x01(\t\x12\x18\n\x10manufacturer_lot\x18\x07 \x01(\t\x12\x19\n\x11manufacturer_line\x18\x08 \x01(\t\"t\n\x11InstancingWarrant\x12\x0f\n\x07version\x18\x01 \x01(\r\x12#\n\x05token\x18\x02 \x01(\x0b\x32\x14.pbose.protobuf.PbWS\x12)\n\x0bprivate_key\x18\x03 \x01(\x0b\x32\x14.pbose.protobuf.PbWKb\x06proto3')
  ,
  dependencies=[pbose_dot_protobuf_dot_PbWK__pb2.DESCRIPTOR,pbose_dot_protobuf_dot_PbWS__pb2.DESCRIPTOR,])




_INSTANCINGTOKENCLAIMS = _descriptor.Descriptor(
  name='InstancingTokenClaims',
  full_name='i4t.protobuf.InstancingTokenClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='i4t.protobuf.InstancingTokenClaims.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial', full_name='i4t.protobuf.InstancingTokenClaims.serial', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sku', full_name='i4t.protobuf.InstancingTokenClaims.sku', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upc', full_name='i4t.protobuf.InstancingTokenClaims.upc', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer_name', full_name='i4t.protobuf.InstancingTokenClaims.manufacturer_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer_location', full_name='i4t.protobuf.InstancingTokenClaims.manufacturer_location', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer_lot', full_name='i4t.protobuf.InstancingTokenClaims.manufacturer_lot', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer_line', full_name='i4t.protobuf.InstancingTokenClaims.manufacturer_line', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=320,
)


_INSTANCINGWARRANT = _descriptor.Descriptor(
  name='InstancingWarrant',
  full_name='i4t.protobuf.InstancingWarrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='i4t.protobuf.InstancingWarrant.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='i4t.protobuf.InstancingWarrant.token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='i4t.protobuf.InstancingWarrant.private_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=438,
)

_INSTANCINGTOKENCLAIMS.fields_by_name['public_key'].message_type = pbose_dot_protobuf_dot_PbWK__pb2._PBWK
_INSTANCINGWARRANT.fields_by_name['token'].message_type = pbose_dot_protobuf_dot_PbWS__pb2._PBWS
_INSTANCINGWARRANT.fields_by_name['private_key'].message_type = pbose_dot_protobuf_dot_PbWK__pb2._PBWK
DESCRIPTOR.message_types_by_name['InstancingTokenClaims'] = _INSTANCINGTOKENCLAIMS
DESCRIPTOR.message_types_by_name['InstancingWarrant'] = _INSTANCINGWARRANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InstancingTokenClaims = _reflection.GeneratedProtocolMessageType('InstancingTokenClaims', (_message.Message,), dict(
  DESCRIPTOR = _INSTANCINGTOKENCLAIMS,
  __module__ = 'i4t.protobuf.Instancing_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.InstancingTokenClaims)
  ))
_sym_db.RegisterMessage(InstancingTokenClaims)

InstancingWarrant = _reflection.GeneratedProtocolMessageType('InstancingWarrant', (_message.Message,), dict(
  DESCRIPTOR = _INSTANCINGWARRANT,
  __module__ = 'i4t.protobuf.Instancing_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.InstancingWarrant)
  ))
_sym_db.RegisterMessage(InstancingWarrant)


# @@protoc_insertion_point(module_scope)
