# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: i4t/protobuf/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pbose.protobuf import PbWK_pb2 as pbose_dot_protobuf_dot_PbWK__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='i4t/protobuf/common.proto',
  package='i4t.protobuf',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x19i4t/protobuf/common.proto\x12\x0ci4t.protobuf\x1a\x19pbose/protobuf/PbWK.proto\"\xd7\x01\n\x08HashType\"\xca\x01\n\x04\x45num\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MD5\x10)\x12\x08\n\x04SHA1\x10*\x12\n\n\x06SHA224\x10+\x12\n\n\x06SHA256\x10,\x12\n\n\x06SHA384\x10-\x12\n\n\x06SHA512\x10.\x12\x0e\n\nSHA512_224\x10/\x12\x0e\n\nSHA512_256\x10\x30\x12\x0c\n\x08SHA3_224\x10\x31\x12\x0c\n\x08SHA3_256\x10\x32\x12\x0c\n\x08SHA3_384\x10\x33\x12\x0c\n\x08SHA3_512\x10\x34\x12\x0c\n\x08SHAKE128\x10\x35\x12\x0c\n\x08SHAKE256\x10\x36\"_\n\x16\x41pplicationInformation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\nconnection\x18\x02 \x01(\x0b\x32#.i4t.protobuf.ConnectionInformation\"\x80\x01\n\x15\x43onnectionInformation\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.i4t.protobuf.ConnectionInformationType.Enum\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x0f\n\x07\x63hannel\x18\x04 \x01(\t\"\x99\x01\n\x19\x43onnectionInformationType\"|\n\x04\x45num\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MQTT\x10\x01\x12\t\n\x05MQTTS\x10\x02\x12\x08\n\x04HTTP\x10\x03\x12\t\n\x05HTTPS\x10\x04\x12\x08\n\x04\x43OAP\x10\x05\x12\t\n\x05\x43OAPS\x10\x06\x12\x06\n\x02WS\x10\x07\x12\x07\n\x03WSS\x10\x08\x12\n\n\x06WEBRTC\x10\t\x12\x0b\n\x07WEBRTCS\x10\n\"q\n\x0fPeerInformation\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.i4t.protobuf.PeerInformationType.Enum\x12(\n\npublic_key\x18\x02 \x01(\x0b\x32\x14.pbose.protobuf.PbWK\"*\n\x13PeerInformationType\"\x13\n\x04\x45num\x12\x0b\n\x07UNKNOWN\x10\x00\x62\x06proto3')
  ,
  dependencies=[pbose_dot_protobuf_dot_PbWK__pb2.DESCRIPTOR,])



_HASHTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='i4t.protobuf.HashType.Enum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MD5', index=1, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA1', index=2, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA224', index=3, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=4, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA384', index=5, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA512', index=6, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA512_224', index=7, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA512_256', index=8, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA3_224', index=9, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA3_256', index=10, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA3_384', index=11, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA3_512', index=12, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHAKE128', index=13, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHAKE256', index=14, number=54,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=84,
  serialized_end=286,
)
_sym_db.RegisterEnumDescriptor(_HASHTYPE_ENUM)

_CONNECTIONINFORMATIONTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='i4t.protobuf.ConnectionInformationType.Enum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MQTT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MQTTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTTP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HTTPS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COAP', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COAPS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WSS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBRTC', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEBRTCS', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=546,
  serialized_end=670,
)
_sym_db.RegisterEnumDescriptor(_CONNECTIONINFORMATIONTYPE_ENUM)

_PEERINFORMATIONTYPE_ENUM = _descriptor.EnumDescriptor(
  name='Enum',
  full_name='i4t.protobuf.PeerInformationType.Enum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=84,
  serialized_end=103,
)
_sym_db.RegisterEnumDescriptor(_PEERINFORMATIONTYPE_ENUM)


_HASHTYPE = _descriptor.Descriptor(
  name='HashType',
  full_name='i4t.protobuf.HashType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HASHTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=286,
)


_APPLICATIONINFORMATION = _descriptor.Descriptor(
  name='ApplicationInformation',
  full_name='i4t.protobuf.ApplicationInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='i4t.protobuf.ApplicationInformation.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection', full_name='i4t.protobuf.ApplicationInformation.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=383,
)


_CONNECTIONINFORMATION = _descriptor.Descriptor(
  name='ConnectionInformation',
  full_name='i4t.protobuf.ConnectionInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='i4t.protobuf.ConnectionInformation.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host', full_name='i4t.protobuf.ConnectionInformation.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='i4t.protobuf.ConnectionInformation.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel', full_name='i4t.protobuf.ConnectionInformation.channel', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=514,
)


_CONNECTIONINFORMATIONTYPE = _descriptor.Descriptor(
  name='ConnectionInformationType',
  full_name='i4t.protobuf.ConnectionInformationType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTIONINFORMATIONTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=670,
)


_PEERINFORMATION = _descriptor.Descriptor(
  name='PeerInformation',
  full_name='i4t.protobuf.PeerInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='i4t.protobuf.PeerInformation.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='i4t.protobuf.PeerInformation.public_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=785,
)


_PEERINFORMATIONTYPE = _descriptor.Descriptor(
  name='PeerInformationType',
  full_name='i4t.protobuf.PeerInformationType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PEERINFORMATIONTYPE_ENUM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=829,
)

_HASHTYPE_ENUM.containing_type = _HASHTYPE
_APPLICATIONINFORMATION.fields_by_name['connection'].message_type = _CONNECTIONINFORMATION
_CONNECTIONINFORMATION.fields_by_name['type'].enum_type = _CONNECTIONINFORMATIONTYPE_ENUM
_CONNECTIONINFORMATIONTYPE_ENUM.containing_type = _CONNECTIONINFORMATIONTYPE
_PEERINFORMATION.fields_by_name['type'].enum_type = _PEERINFORMATIONTYPE_ENUM
_PEERINFORMATION.fields_by_name['public_key'].message_type = pbose_dot_protobuf_dot_PbWK__pb2._PBWK
_PEERINFORMATIONTYPE_ENUM.containing_type = _PEERINFORMATIONTYPE
DESCRIPTOR.message_types_by_name['HashType'] = _HASHTYPE
DESCRIPTOR.message_types_by_name['ApplicationInformation'] = _APPLICATIONINFORMATION
DESCRIPTOR.message_types_by_name['ConnectionInformation'] = _CONNECTIONINFORMATION
DESCRIPTOR.message_types_by_name['ConnectionInformationType'] = _CONNECTIONINFORMATIONTYPE
DESCRIPTOR.message_types_by_name['PeerInformation'] = _PEERINFORMATION
DESCRIPTOR.message_types_by_name['PeerInformationType'] = _PEERINFORMATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HashType = _reflection.GeneratedProtocolMessageType('HashType', (_message.Message,), dict(
  DESCRIPTOR = _HASHTYPE,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.HashType)
  ))
_sym_db.RegisterMessage(HashType)

ApplicationInformation = _reflection.GeneratedProtocolMessageType('ApplicationInformation', (_message.Message,), dict(
  DESCRIPTOR = _APPLICATIONINFORMATION,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.ApplicationInformation)
  ))
_sym_db.RegisterMessage(ApplicationInformation)

ConnectionInformation = _reflection.GeneratedProtocolMessageType('ConnectionInformation', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONINFORMATION,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.ConnectionInformation)
  ))
_sym_db.RegisterMessage(ConnectionInformation)

ConnectionInformationType = _reflection.GeneratedProtocolMessageType('ConnectionInformationType', (_message.Message,), dict(
  DESCRIPTOR = _CONNECTIONINFORMATIONTYPE,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.ConnectionInformationType)
  ))
_sym_db.RegisterMessage(ConnectionInformationType)

PeerInformation = _reflection.GeneratedProtocolMessageType('PeerInformation', (_message.Message,), dict(
  DESCRIPTOR = _PEERINFORMATION,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.PeerInformation)
  ))
_sym_db.RegisterMessage(PeerInformation)

PeerInformationType = _reflection.GeneratedProtocolMessageType('PeerInformationType', (_message.Message,), dict(
  DESCRIPTOR = _PEERINFORMATIONTYPE,
  __module__ = 'i4t.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.PeerInformationType)
  ))
_sym_db.RegisterMessage(PeerInformationType)


# @@protoc_insertion_point(module_scope)
