# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: i4t/protobuf/Session.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pbose.protobuf import PbWK_pb2 as pbose_dot_protobuf_dot_PbWK__pb2
from pbose.protobuf import PbWS_pb2 as pbose_dot_protobuf_dot_PbWS__pb2
from i4t.protobuf import common_pb2 as i4t_dot_protobuf_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='i4t/protobuf/Session.proto',
  package='i4t.protobuf',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1ai4t/protobuf/Session.proto\x12\x0ci4t.protobuf\x1a\x19pbose/protobuf/PbWK.proto\x1a\x19pbose/protobuf/PbWS.proto\x1a\x19i4t/protobuf/common.proto\"\xad\x01\n\x12SessionTokenClaims\x12\x35\n\x07session\x18\x01 \x01(\x0b\x32$.i4t.protobuf.ApplicationInformation\x12\x30\n\tauthority\x18\x02 \x01(\x0b\x32\x1d.i4t.protobuf.PeerInformation\x12.\n\x07\x63lients\x18\x03 \x03(\x0b\x32\x1d.i4t.protobuf.PeerInformation\"t\n\x0eSessionWarrant\x12\x0f\n\x07version\x18\x01 \x01(\r\x12#\n\x05token\x18\x02 \x01(\x0b\x32\x14.pbose.protobuf.PbWS\x12,\n\x0e\x65ncryption_key\x18\x03 \x01(\x0b\x32\x14.pbose.protobuf.PbWKb\x06proto3')
  ,
  dependencies=[pbose_dot_protobuf_dot_PbWK__pb2.DESCRIPTOR,pbose_dot_protobuf_dot_PbWS__pb2.DESCRIPTOR,i4t_dot_protobuf_dot_common__pb2.DESCRIPTOR,])




_SESSIONTOKENCLAIMS = _descriptor.Descriptor(
  name='SessionTokenClaims',
  full_name='i4t.protobuf.SessionTokenClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='i4t.protobuf.SessionTokenClaims.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authority', full_name='i4t.protobuf.SessionTokenClaims.authority', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clients', full_name='i4t.protobuf.SessionTokenClaims.clients', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=299,
)


_SESSIONWARRANT = _descriptor.Descriptor(
  name='SessionWarrant',
  full_name='i4t.protobuf.SessionWarrant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='i4t.protobuf.SessionWarrant.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='i4t.protobuf.SessionWarrant.token', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encryption_key', full_name='i4t.protobuf.SessionWarrant.encryption_key', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=417,
)

_SESSIONTOKENCLAIMS.fields_by_name['session'].message_type = i4t_dot_protobuf_dot_common__pb2._APPLICATIONINFORMATION
_SESSIONTOKENCLAIMS.fields_by_name['authority'].message_type = i4t_dot_protobuf_dot_common__pb2._PEERINFORMATION
_SESSIONTOKENCLAIMS.fields_by_name['clients'].message_type = i4t_dot_protobuf_dot_common__pb2._PEERINFORMATION
_SESSIONWARRANT.fields_by_name['token'].message_type = pbose_dot_protobuf_dot_PbWS__pb2._PBWS
_SESSIONWARRANT.fields_by_name['encryption_key'].message_type = pbose_dot_protobuf_dot_PbWK__pb2._PBWK
DESCRIPTOR.message_types_by_name['SessionTokenClaims'] = _SESSIONTOKENCLAIMS
DESCRIPTOR.message_types_by_name['SessionWarrant'] = _SESSIONWARRANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SessionTokenClaims = _reflection.GeneratedProtocolMessageType('SessionTokenClaims', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONTOKENCLAIMS,
  __module__ = 'i4t.protobuf.Session_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.SessionTokenClaims)
  ))
_sym_db.RegisterMessage(SessionTokenClaims)

SessionWarrant = _reflection.GeneratedProtocolMessageType('SessionWarrant', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONWARRANT,
  __module__ = 'i4t.protobuf.Session_pb2'
  # @@protoc_insertion_point(class_scope:i4t.protobuf.SessionWarrant)
  ))
_sym_db.RegisterMessage(SessionWarrant)


# @@protoc_insertion_point(module_scope)
